==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/BlobBackupDatasourceParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters to be used during configuration of backup of blobs
 * @property containersList List of containers to be backed up during configuration of backup of blobs
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'BlobBackupDatasourceParameters'.
 */
public data class BlobBackupDatasourceParametersArgs(
    public val containersList: Output<List<String>>,
    public val objectType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs.builder()
            .containersList(containersList.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobBackupDatasourceParametersArgs].
 */
@PulumiTagMarker
public class BlobBackupDatasourceParametersArgsBuilder internal constructor() {
    private var containersList: Output<List<String>>? = null

    private var objectType: Output<String>? = null

    /**
     * @param value List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("rqpkukubwkfjqwmb")
    public suspend fun containersList(`value`: Output<List<String>>) {
        this.containersList = value
    }

    @JvmName("ihhagfacfyscamap")
    public suspend fun containersList(vararg values: Output<String>) {
        this.containersList = Output.all(values.asList())
    }

    /**
     * @param values List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("shbgoxtkwvbcfybc")
    public suspend fun containersList(values: List<Output<String>>) {
        this.containersList = Output.all(values)
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'BlobBackupDatasourceParameters'.
     */
    @JvmName("yyfcxcnanvgcwdkq")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("arjqgggeduhhxtrp")
    public suspend fun containersList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containersList = mapped
    }

    /**
     * @param values List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("ijsvromyqiphpfry")
    public suspend fun containersList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containersList = mapped
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'BlobBackupDatasourceParameters'.
     */
    @JvmName("fthryerwlowpwpgt")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): BlobBackupDatasourceParametersArgs = BlobBackupDatasourceParametersArgs(
        containersList = containersList ?: throw PulumiNullFieldException("containersList"),
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/BlobBackupDatasourceParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters to be used during configuration of backup of blobs
 * @property containersList List of containers to be backed up during configuration of backup of blobs
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'BlobBackupDatasourceParameters'.
 */
public data class BlobBackupDatasourceParametersArgs(
    public val containersList: Output<List<String>>,
    public val objectType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.BlobBackupDatasourceParametersArgs.builder()
            .containersList(containersList.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobBackupDatasourceParametersArgs].
 */
@PulumiTagMarker
public class BlobBackupDatasourceParametersArgsBuilder internal constructor() {
    private var containersList: Output<List<String>>? = null

    private var objectType: Output<String>? = null

    /**
     * @param value List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("yispwvygfvhxyomg")
    public suspend fun containersList(`value`: Output<List<String>>) {
        this.containersList = value
    }

    @JvmName("mununddnlfvqyawv")
    public suspend fun containersList(vararg values: Output<String>) {
        this.containersList = Output.all(values.asList())
    }

    /**
     * @param values List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("mbnsxqieqcbdcove")
    public suspend fun containersList(values: List<Output<String>>) {
        this.containersList = Output.all(values)
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'BlobBackupDatasourceParameters'.
     */
    @JvmName("efpkfxlikoqmfqfe")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("ilgpysvblivvdmlt")
    public suspend fun containersList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containersList = mapped
    }

    /**
     * @param values List of containers to be backed up during configuration of backup of blobs
     */
    @JvmName("djyfrkmphqahjiwd")
    public suspend fun containersList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containersList = mapped
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'BlobBackupDatasourceParameters'.
     */
    @JvmName("putierjvyyalpouj")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): BlobBackupDatasourceParametersArgs = BlobBackupDatasourceParametersArgs(
        containersList = containersList ?: throw PulumiNullFieldException("containersList"),
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}
